Hi,
I've been working through the renames_pending file in apr.
I have already sent a patch to rename apr_ansi_time_to_apr_time and
apr_exploded_time_t to dev@apr; this is the companion patch for httpd-2.0
Cheers,
-Thom
Index: include/util_time.h
===================================================================
RCS file: /home/cvspublic/httpd-2.0/include/util_time.h,v
retrieving revision 1.1
diff -u -u -3 -r1.1 util_time.h
--- include/util_time.h 19 Sep 2001 06:53:25 -0000      1.1
+++ include/util_time.h 6 Mar 2002 11:56:50 -0000
@@ -83,9 +83,9 @@
  *       that need to explode the current time multiple times per second,
  *       like loggers.
  * @return APR_SUCCESS iff successful
- * @deffunc apr_status_t ap_explode_recent_localtime(apr_exploded_time_t *tm, 
apr_time_t t);
+ * @deffunc apr_status_t ap_explode_recent_localtime(apr_time_exp_t *tm, apr_time_t 
+t);
  */
-AP_DECLARE(apr_status_t) ap_explode_recent_localtime(apr_exploded_time_t *tm,
+AP_DECLARE(apr_status_t) ap_explode_recent_localtime(apr_time_exp_t *tm,
                                                      apr_time_t t);
 
 /**
@@ -98,9 +98,9 @@
  *       that need to explode the current time multiple times per second,
  *       like loggers.
  * @return APR_SUCCESS iff successful
- * @deffunc apr_status_t ap_explode_recent_gmt(apr_exploded_time_t *tm, apr_time_t t);
+ * @deffunc apr_status_t ap_explode_recent_gmt(apr_time_exp_t *tm, apr_time_t t);
  */
-AP_DECLARE(apr_status_t) ap_explode_recent_gmt(apr_exploded_time_t *tm,
+AP_DECLARE(apr_status_t) ap_explode_recent_gmt(apr_time_exp_t *tm,
                                                apr_time_t t);
 
 
Index: modules/dav/fs/repos.c
===================================================================
RCS file: /home/cvspublic/httpd-2.0/modules/dav/fs/repos.c,v
retrieving revision 1.64
diff -u -u -3 -r1.64 repos.c
--- modules/dav/fs/repos.c      27 Jan 2002 12:39:25 -0000      1.64
+++ modules/dav/fs/repos.c      6 Mar 2002 11:57:01 -0000
@@ -303,7 +303,7 @@
 /* NOTE: buf must be at least DAV_TIMEBUF_SIZE chars in size */
 static void dav_format_time(int style, apr_time_t sec, char *buf)
 {
-    apr_exploded_time_t tms;
+    apr_time_exp_t tms;
     
     /* ### what to do if fails? */
     (void) apr_explode_gmt(&tms, sec);
Index: modules/generators/mod_autoindex.c
===================================================================
RCS file: /home/cvspublic/httpd-2.0/modules/generators/mod_autoindex.c,v
retrieving revision 1.98
diff -u -u -3 -r1.98 mod_autoindex.c
--- modules/generators/mod_autoindex.c  1 Mar 2002 20:44:20 -0000       1.98
+++ modules/generators/mod_autoindex.c  6 Mar 2002 11:57:14 -0000
@@ -1657,7 +1657,7 @@
             if (!(autoindex_opts & SUPPRESS_LAST_MOD)) {
                 if (ar[x]->lm != -1) {
                     char time_str[MAX_STRING_LEN];
-                    apr_exploded_time_t ts;
+                    apr_time_exp_t ts;
                     apr_explode_localtime(&ts, ar[x]->lm);
                     apr_strftime(time_str, &rv, MAX_STRING_LEN, 
                                  "</td><td align=\"right\">%d-%b-%Y %H:%M  ", &ts);
@@ -1740,7 +1740,7 @@
             if (!(autoindex_opts & SUPPRESS_LAST_MOD)) {
                 if (ar[x]->lm != -1) {
                     char time_str[MAX_STRING_LEN];
-                    apr_exploded_time_t ts;
+                    apr_time_exp_t ts;
                     apr_explode_localtime(&ts, ar[x]->lm);
                     apr_strftime(time_str, &rv, MAX_STRING_LEN, 
                                 "%d-%b-%Y %H:%M  ", &ts);
Index: modules/loggers/mod_log_config.c
===================================================================
RCS file: /home/cvspublic/httpd-2.0/modules/loggers/mod_log_config.c,v
retrieving revision 1.77
diff -u -u -3 -r1.77 mod_log_config.c
--- modules/loggers/mod_log_config.c    28 Jan 2002 23:49:39 -0000      1.77
+++ modules/loggers/mod_log_config.c    6 Mar 2002 11:57:23 -0000
@@ -447,7 +447,7 @@
 }
 
 static const char *log_request_time_custom(request_rec *r, char *a,
-                                           apr_exploded_time_t *xt)
+                                           apr_time_exp_t *xt)
 {
     apr_size_t retcode;
     char tstr[MAX_STRING_LEN];
@@ -457,7 +457,7 @@
 
 static const char *log_request_time(request_rec *r, char *a)
 {
-    apr_exploded_time_t xt;
+    apr_time_exp_t xt;
 
     /*
        hi.  i think getting the time again at the end of the request
Index: modules/mappers/mod_rewrite.c
===================================================================
RCS file: /home/cvspublic/httpd-2.0/modules/mappers/mod_rewrite.c,v
retrieving revision 1.98
diff -u -u -3 -r1.98 mod_rewrite.c
--- modules/mappers/mod_rewrite.c       27 Feb 2002 03:52:20 -0000      1.98
+++ modules/mappers/mod_rewrite.c       6 Mar 2002 11:57:47 -0000
@@ -3229,7 +3229,7 @@
 
 static char *current_logtime(request_rec *r)
 {
-    apr_exploded_time_t t;
+    apr_time_exp_t t;
     char tstr[80];
     apr_size_t len;
 
@@ -3413,7 +3413,7 @@
 {
     const char *result;
     char resultbuf[LONG_STRING_LEN];
-    apr_exploded_time_t tm;
+    apr_time_exp_t tm;
     request_rec *rsub;
 
     result = NULL;
Index: modules/metadata/mod_usertrack.c
===================================================================
RCS file: /home/cvspublic/httpd-2.0/modules/metadata/mod_usertrack.c,v
retrieving revision 1.34
diff -u -u -3 -r1.34 mod_usertrack.c
--- modules/metadata/mod_usertrack.c    1 Oct 2001 15:47:12 -0000       1.34
+++ modules/metadata/mod_usertrack.c    6 Mar 2002 11:57:57 -0000
@@ -155,7 +155,7 @@
                                   dcfg->cookie_name, cookiebuf);
 
         if ((dcfg->style == CT_UNSET) || (dcfg->style == CT_NETSCAPE)) {
-           apr_exploded_time_t tms;
+           apr_time_exp_t tms;
             apr_explode_gmt(&tms, r->request_time 
                                 + cls->expires * APR_USEC_PER_SEC);
             new_cookie = apr_psprintf(r->pool,
Index: modules/ssl/ssl_engine_log.c
===================================================================
RCS file: /home/cvspublic/httpd-2.0/modules/ssl/ssl_engine_log.c,v
retrieving revision 1.10
diff -u -u -3 -r1.10 ssl_engine_log.c
--- modules/ssl/ssl_engine_log.c        27 Feb 2002 00:58:17 -0000      1.10
+++ modules/ssl/ssl_engine_log.c        6 Mar 2002 11:58:03 -0000
@@ -170,7 +170,7 @@
     char str[1024];
     char *nstr;
     apr_size_t len;
-    apr_exploded_time_t t;
+    apr_time_exp_t t;
     va_list ap;
     int add;
     int i;
Index: server/util.c
===================================================================
RCS file: /home/cvspublic/httpd-2.0/server/util.c,v
retrieving revision 1.119
diff -u -u -3 -r1.119 util.c
--- server/util.c       27 Jan 2002 07:49:05 -0000      1.119
+++ server/util.c       6 Mar 2002 11:58:11 -0000
@@ -142,7 +142,7 @@
     apr_size_t retcode;
     char ts[MAX_STRING_LEN];
     char tf[MAX_STRING_LEN];
-    apr_exploded_time_t xt;
+    apr_time_exp_t xt;
 
     if (gmt) {
        const char *f;
Index: support/rotatelogs.c
===================================================================
RCS file: /home/cvspublic/httpd-2.0/support/rotatelogs.c,v
retrieving revision 1.17
diff -u -u -3 -r1.17 rotatelogs.c
--- support/rotatelogs.c        10 Oct 2001 13:02:22 -0000      1.17
+++ support/rotatelogs.c        6 Mar 2002 11:58:15 -0000
@@ -161,7 +161,7 @@
             int tLogStart = (now / tRotation) * tRotation;
             if (use_strftime) {
                apr_time_t tNow = tLogStart * APR_USEC_PER_SEC;
-                apr_exploded_time_t e;
+                apr_time_exp_t e;
                 apr_size_t rs;
 
                 apr_explode_gmt(&e, tNow);


Reply via email to
Index: server/util_time.c
===================================================================
RCS file: /home/cvspublic/httpd-2.0/server/util_time.c,v
retrieving revision 1.2
diff -u -u -3 -r1.2 util_time.c
--- server/util_time.c  1 Oct 2001 15:49:02 -0000       1.2
+++ server/util_time.c  6 Mar 2002 11:58:13 -0000
@@ -60,7 +60,7 @@
 
 struct exploded_time_cache_element {
     apr_int64_t t;
-    apr_exploded_time_t xt;
+    apr_time_exp_t xt;
     apr_int64_t t_validate; /* please see comments in cached_explode() */
 };
 
@@ -71,7 +71,7 @@
 static struct exploded_time_cache_element exploded_cache_gmt[TIME_CACHE_SIZE];
 
 
-static apr_status_t cached_explode(apr_exploded_time_t *xt, apr_time_t t,
+static apr_status_t cached_explode(apr_time_exp_t *xt, apr_time_t t,
                                    struct exploded_time_cache_element *cache,
                                    int use_gmt)
 {
@@ -86,7 +86,7 @@
      * exploded time for the current second (vs the time
      * 'now - AP_TIME_RECENT_THRESHOLD' seconds ago).  If the
      * cached value is for the current time, we use it.  Otherwise,
      * we compute the apr_exploded_time_t and store it in this
      * cache element. Note that the timestamp in the cache
      * element is updated only after the exploded time.  Thus
      * if two threads hit this cache element simultaneously
@@ -139,7 +139,7 @@
         else {
             /* Valid snapshot */
             memcpy(xt, &(cache_element_snapshot.xt),
-                   sizeof(apr_exploded_time_t));
+                   sizeof(apr_time_exp_t));
         }
     }
     else {
@@ -154,7 +154,7 @@
             return r;
         }
         cache_element->t = seconds;
-        memcpy(&(cache_element->xt), xt, sizeof(apr_exploded_time_t));
+        memcpy(&(cache_element->xt), xt, sizeof(apr_time_exp_t));
         cache_element->t_validate = seconds;
     }
     xt->tm_usec = (int)(t % APR_USEC_PER_SEC);
@@ -162,13 +162,13 @@
 }
 
 
-AP_DECLARE(apr_status_t) ap_explode_recent_localtime(apr_exploded_time_t * tm,
+AP_DECLARE(apr_status_t) ap_explode_recent_localtime(apr_time_exp_t * tm,
                                                      apr_time_t t)
 {
     return cached_explode(tm, t, exploded_cache_localtime, 0);
 }
 
-AP_DECLARE(apr_status_t) ap_explode_recent_gmt(apr_exploded_time_t * tm,
+AP_DECLARE(apr_status_t) ap_explode_recent_gmt(apr_time_exp_t * tm,
                                                apr_time_t t)
 {
     return cached_explode(tm, t, exploded_cache_gmt, 1);
@@ -86,7 +86,7 @@
      * 'now - AP_TIME_RECENT_THRESHOLD' seconds ago).  If the
      * cached value is for the current time, we use it.  Otherwise,
-     * we compute the apr_exploded_time_t and store it in this
+     * we compute the apr_time_exp_t and store it in this
      * cache element. Note that the timestamp in the cache
      * element is updated only after the exploded time.  Thus